summaryrefslogtreecommitdiffstats
path: root/src/historyview.h
diff options
context:
space:
mode:
authorSlávek Banko <slavek.banko@axis.cz>2013-10-08 00:13:25 +0200
committerSlávek Banko <slavek.banko@axis.cz>2013-10-08 05:14:53 +0200
commit84f5a315c3429b47a7eff15e626e2efdbe4f6e5e (patch)
tree770861aa9033e1dc6c5168358194ff85b32dd429 /src/historyview.h
parent57d8bb3d12aed373eee08915f0ff19f5233aabe3 (diff)
downloadkscope-84f5a315c3429b47a7eff15e626e2efdbe4f6e5e.tar.gz
kscope-84f5a315c3429b47a7eff15e626e2efdbe4f6e5e.zip
Initial TQt conversion
Diffstat (limited to 'src/historyview.h')
-rw-r--r--src/historyview.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/historyview.h b/src/historyview.h
index 38a0c46..ab34b37 100644
--- a/src/historyview.h
+++ b/src/historyview.h
@@ -32,14 +32,14 @@
/**
* A list view item for holding position history records.
* A QListViewItem cannot reference its preceding item, which is required to
* create a stack-like history list. Therefore a HistoryItem object
* stores a pointer to the item just above it in the list. The pointer is
* persistent, since the list cannot be sorted.
* @author Elad Lahav
*/
-class HistoryItem : public QListViewItem
+class HistoryItem : public TQListViewItem
{
public:
/**
@@ -49,9 +49,9 @@ public:
* @param sLine The line number
* @param sText The contents of the line in the given file
*/
- HistoryItem(QListView* pList, QString sFile, QString sLine,
- QString sText) :
- QListViewItem(pList, "", sFile, sLine, sText),
+ HistoryItem(TQListView* pList, TQString sFile, TQString sLine,
+ TQString sText) :
+ TQListViewItem(pList, "", sFile, sLine, sText),
m_pPrevSibling(NULL) {
HistoryItem* pNext;
@@ -76,16 +76,16 @@ class HistoryView : public QueryView
{
Q_OBJECT
public:
- HistoryView(QWidget* pParent = 0, const char* szName = 0);
+ HistoryView(TQWidget* pParent = 0, const char* szName = 0);
~HistoryView();
- virtual void addRecord(const QString&, const QString&, const QString&,
- const QString&, QListViewItem*);
+ virtual void addRecord(const TQString&, const TQString&, const TQString&,
+ const TQString&, TQListViewItem*);
virtual void selectNext();
virtual void selectPrev();
protected slots:
- virtual void slotRemoveItem(QListViewItem*);
+ virtual void slotRemoveItem(TQListViewItem*);
};
#endif
@@ -32,14 +32,14 @@
/**
* A list view item for holding position history records.
- * A QListViewItem cannot reference its preceding item, which is required to
+ * A TQListViewItem cannot reference its preceding item, which is required to
* create a stack-like history list. Therefore a HistoryItem object
* stores a pointer to the item just above it in the list. The pointer is